require 'spec_helper'

describe Scripting::AppDefaults do

  before :each do
    @stdout = ''
    STDOUT.stub(:write) { |*args| @stdout << args.join }

    @stderr = ''
    STDERR.stub(:write) { |*args| @stderr << args.join }
  end

  it "should define default options and switches when using AppDefaults plugin" do
    app = Scripting::create_application do
      plugin Scripting::AppDefaults
    end
    app.options.verbose.should be_false
    app.options.debug.should be_false
    app.parse! ["-vD"]
    app.options.verbose.should be_true
    app.options.debug.should be_true
  end

  it "should terminate command line processing and clear work when -h is passed with default switches" do
    app = Scripting::create_application do
      plugin Scripting::AppDefaults
      work { puts 7 * 6 }
    end
    @stderr.should be_empty
    app.work.should_not be_empty
    app.parse! ["-h"]
    @stderr.should_not be_empty
    app.work.should be_empty
  end
end
