require 'spec_helper'

describe Scripting::Application do

  it "should run a work block" do
    app = Scripting::create_application do
      work { options.work1_ran = true }
    end

    app.options.work1_ran.should be_nil
    app.run!
    app.options.work1_ran.should be_true
  end

  it "should run many work blocks in order" do
    app = Scripting::create_application do
      work { options.work_runs = [1] }
      work { options.work_runs.push 2 }
      work { options.work_runs.push 3 }
    end

    app.options.work_runs.should be_nil
    app.run!
    app.options.work_runs.should == [1,2,3]
  end

  it "should pass extra args to work blocks" do
    app = Scripting::create_application do
      work do |*extra_args|
        action = extra_args.first
        options.action = action
      end
    end

    app.options.action.should be_nil
    app.run! ["digest"]
    app.options.action.should == "digest"
  end

end
