require 'spec_helper'

describe Scripting::Options do

  it "should assign without =" do
    opts = Scripting::Options.new
    opts.first :a
    opts.second :b

    opts.first.should == :a
    opts.second.should == :b
  end

  it "should assign with =" do
    opts = Scripting::Options.new
    opts.first = :a
    opts.second = :b
    opts.third = 3

    opts.first.should == :a
    opts.second.should == :b
    opts.third.should == 3
  end

  it "should assign with or without =" do
    opts = Scripting::Options.new
    opts.first = :a
    opts.second :b
    opts.third = 3
    opts.fourth "4"

    opts.first.should == :a
    opts.second.should == :b
    opts.third.should == 3
    opts.fourth.should == "4"
  end

  it "should treat predicates as truthy" do
    opts = Scripting::Options.new
    opts.a_true = true
    opts.a_false = false
    opts.a_nil = nil
    opts.a_forty_two = 42
    opts.a_hello = "hello"
    opts.a_colon_hello = :hello

    opts.a_true?.should be_true
    opts.a_false?.should be_false
    opts.a_nil?.should be_false
    opts.a_forty_two?.should be_true
    opts.a_hello?.should be_true
    opts.a_colon_hello?.should be_true
  end

  it "should assign blocks and call the block for each visit" do
    opts = Scripting::Options.new
    opts.block { true }
    opts.block.should be_true
  end

  it "should assign blocks and invoke them in the scope of the entire options instance" do
    opts = Scripting::Options.new
    opts.count 0
    opts.block { self.count += 1 }

    opts.block.should == 1
    opts.block.should == 2
  end

end